@@ -29,21 +29,14 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
     and accessing explanations for test instances.
     """
 
-    def __init__(
-        self, calibrated_explainer, X_test, y_threshold, bins, features_to_ignore=None
-    ) -> None:
-        """A class for storing and visualizing calibrated explanations.
-
-        This class is created by :class:`.CalibratedExplainer` and provides methods for managing
-        and accessing explanations for test instances.
-
-        Initialize the CalibratedExplanations object.
+    def __init__(self, calibrated_explainer, x, y_threshold, bins, features_to_ignore=None) -> None:
+        """Initialize the explanation collection for a calibrated explainer.
 
         Parameters
         ----------
         calibrated_explainer : CalibratedExplainer
             The calibrated explainer object.
-        X_test : array-like
+        x : array-like
             The test data.
         y_threshold : float or tuple
             The threshold for regression explanations.
@@ -53,7 +46,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         self.calibrated_explainer: FrozenCalibratedExplainer = FrozenCalibratedExplainer(
             calibrated_explainer
         )
-        self.X_test: np.ndarray = X_test
+        self.x_test: np.ndarray = x
         self.y_threshold: Optional[Union[float, Tuple[float, float], List[Tuple[float, float]]]] = (
             y_threshold
         )
@@ -63,7 +56,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         ] = []
         self.start_index: int = 0
         self.current_index: int = self.start_index
-        self.end_index: int = len(X_test[:, 0])
+        self.end_index: int = len(x[:, 0])
         self.bins: Optional[Sequence[Any]] = bins
         self.total_explain_time: Optional[float] = None
         self.features_to_ignore: List[int] = (
@@ -92,7 +85,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     def __len__(self):
         """Return the number of explanations."""
-        return len(self.X_test[:, 0])
+        return len(self.x_test[:, 0])
 
     def __getitem__(self, key: Union[int, slice, List[int], List[bool], np.ndarray]):
         """Return the explanation for the given key.
@@ -125,7 +118,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
             new_.current_index = new_.start_index
             new_.end_index = len(new_.explanations)
             new_.bins = None if self.bins is None else [self.bins[e.index] for e in new_]
-            new_.X_test = np.array([self.X_test[e.index, :] for e in new_])
+            new_.x_test = np.array([self.x_test[e.index, :] for e in new_])
             if self.y_threshold is None:
                 new_.y_threshold = None
             elif isinstance(self.y_threshold, (int, float)):
@@ -155,7 +148,6 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     def to_batch(self):
         """Serialise the collection into an :class:`ExplanationBatch`."""
-
         from ..plugins.builtins import _collection_to_batch  # lazy import
 
         return _collection_to_batch(self)
@@ -163,7 +155,6 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
     @classmethod
     def from_batch(cls, batch):
         """Reconstruct a collection from an :class:`ExplanationBatch`."""
-
         container = batch.collection_metadata.get("container")
         if container is None:
             raise ValueError("ExplanationBatch is missing container metadata")
@@ -173,7 +164,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def prediction_interval(self) -> List[Tuple[Optional[float], Optional[float]]]:
-        """Get the prediction intervals from each prediction.
+        """Return the prediction intervals for each explanation.
 
         Returns
         -------
@@ -184,7 +175,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def predict(self) -> List[Any]:
-        """Get the predictions from each prediction.
+        """Return the scalar prediction for every explanation.
 
         Returns
         -------
@@ -196,6 +187,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
     # ---- Rich baseline exposure (Phase 1A golden snapshot enrichment) ----
     @property
     def feature_names(self):  # consistent naming with underlying explainer
+        """Return cached feature names sourced from the underlying explainer."""
         if self._feature_names_cache is None:
             # Underlying FrozenCalibratedExplainer exposes feature_names via original explainer
             try:
@@ -206,6 +198,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def class_labels(self):
+        """Return class labels for classification explanations if available."""
         if self._class_labels_cache is None:
             try:
                 labels = getattr(self.calibrated_explainer._explainer, "class_labels", None)  # noqa: SLF001
@@ -230,6 +223,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def probabilities(self):  # classification only
+        """Return cached probability matrices for classification explanations."""
         if self._probabilities_cache is None:
             try:
                 # Each explanation may store:
@@ -254,6 +248,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def lower(self):  # regression only
+        """Return cached lower bounds for regression prediction intervals."""
         if self._lower_cache is None:
             try:
                 lows = [
@@ -267,6 +262,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
 
     @property
     def upper(self):  # regression only
+        """Return cached upper bounds for regression prediction intervals."""
         if self._upper_cache is None:
             try:
                 highs = [
@@ -369,7 +365,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         self : object
             Returns the instance of the class with explanations finalized.
         """
-        for i, instance in enumerate(self.X_test):
+        for i, instance in enumerate(self.x_test):
             instance_bin = self.bins[i] if self.bins is not None else None
             if self._is_alternative():
                 explanation: Union[FactualExplanation, AlternativeExplanation, FastExplanation]
@@ -400,10 +396,12 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
             self.explanations.append(explanation)
         self.total_explain_time = time() - total_time if total_time is not None else None
         if self._is_alternative():
-            return self.__convert_to_AlternativeExplanations()
+            return self.__convert_to_alternative_explanations()
         return self
 
-    def __convert_to_AlternativeExplanations(self) -> "AlternativeExplanations":
+    def __convert_to_alternative_explanations(self) -> "AlternativeExplanations":
+        """Return an ``AlternativeExplanations`` view sharing this collection's backing data."""
+
         alternative_explanations = AlternativeExplanations.__new__(AlternativeExplanations)
         alternative_explanations.__dict__.update(self.__dict__)
         return alternative_explanations
@@ -437,7 +435,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         - The explanation time for each instance is recorded if `instance_time` is provided.
         - The total explanation time is calculated if `total_time` is provided.
         """
-        for i, instance in enumerate(self.X_test):
+        for i, instance in enumerate(self.x_test):
             instance_bin = self.bins[i] if self.bins is not None else None
             explanation = FastExplanation(
                 self,
@@ -454,11 +452,13 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         self.total_explain_time = time() - total_time if total_time is not None else None
 
     def _get_explainer(self):
-        # """get the explainer object
-        # """
+        """Return the underlying :class:`~calibrated_explanations.core.calibrated_explainer.CalibratedExplainer` instance."""
+
         return self.calibrated_explainer
 
     def _get_rules(self):
+        """Return the materialised rule payload for each explanation in the collection."""
+
         return [
             # pylint: disable=protected-access
             explanation._get_rules()
@@ -527,18 +527,13 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
             raise TypeError("index must be an integer")
         if index < 0:
             raise ValueError("index must be greater than or equal to 0")
-        if index >= len(self.X_test):
+        if index >= len(self.x_test):
             raise ValueError("index must be less than the number of test instances")
         return self.explanations[index]
 
     def _is_alternative(self):
-        # '''The function checks if the explanations are alternatives by checking if the `discretizer` attribute of the `calibrated_explainer` object is an
-        # instance of either `DecileDiscretizer` or `EntropyDiscretizer`.
+        """Return True when the collection represents an alternative explanation workflow."""
 
-        # Returns
-        # -------
-        #     a boolean value indicating whether the explanations are alternatives.
-        # '''
         return isinstance(
             self.calibrated_explainer.discretizer, (RegressorDiscretizer, EntropyDiscretizer)
         )
@@ -628,7 +623,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         """
         _, lime_exp = self.calibrated_explainer._preload_lime()  # pylint: disable=protected-access
         exp = []
-        for explanation in self.explanations:  # range(len(self.X_test[:,0])):
+        for explanation in self.explanations:  # range(len(self.x[:,0])):
             tmp = deepcopy(lime_exp)
             tmp.intercept[1] = 0
             tmp.local_pred = explanation.prediction["predict"]
@@ -654,7 +649,7 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
                 tmp.local_exp[1][j] = (f, feature_weights[f])
             del tmp.local_exp[1][num_to_show:]
             tmp.domain_mapper.discretized_feature_names = rules
-            tmp.domain_mapper.feature_values = explanation.X_test
+            tmp.domain_mapper.feature_values = explanation.x_test
             exp.append(tmp)
         return exp
 
@@ -668,11 +663,11 @@ class CalibratedExplanations:  # pylint: disable=too-many-instance-attributes
         """
         _, shap_exp = self.calibrated_explainer._preload_shap()  # pylint: disable=protected-access
         shap_exp.base_values = np.resize(shap_exp.base_values, len(self))
-        shap_exp.values = np.resize(shap_exp.values, (len(self), len(self.X_test[0, :])))
-        shap_exp.data = self.X_test
-        for i, explanation in enumerate(self.explanations):  # range(len(self.X_test[:,0])):
+        shap_exp.values = np.resize(shap_exp.values, (len(self), len(self.x_test[0, :])))
+        shap_exp.data = self.x_test
+        for i, explanation in enumerate(self.explanations):  # range(len(self.x[:,0])):
             # shap_exp.base_values[i] = explanation.prediction['predict']
-            for f in range(len(self.X_test[0, :])):
+            for f in range(len(self.x_test[0, :])):
                 shap_exp.values[i][f] = -explanation.feature_weights["predict"][f]
         return shap_exp
 
@@ -801,7 +796,7 @@ class FrozenCalibratedExplainer:
         self._explainer = deepcopy(explainer)
 
     @property
-    def X_cal(self):
+    def x_cal(self):
         """
         Retrieves the calibrated feature matrix from the underlying explainer.
 
@@ -811,7 +806,7 @@ class FrozenCalibratedExplainer:
         -------
             numpy.ndarray: The calibrated feature matrix.
         """
-        return self._explainer.X_cal
+        return self._explainer.x_cal
 
     @property
     def y_cal(self):
