@@ -1,3 +1,5 @@
+"""Lightweight parallel execution helpers used by optional perf scaffolding."""
+
 from __future__ import annotations
 
 from typing import Callable, Iterable, List, Protocol, Sequence, TypeVar
@@ -7,9 +9,13 @@ R = TypeVar("R")
 
 
 class ParallelBackend(Protocol):
+    """Protocol describing a map-style parallel backend."""
+
     def map(
         self, fn: Callable[[T], R], items: Sequence[T], *, workers: int | None = None
-    ) -> List[R]: ...
+    ) -> List[R]:
+        """Apply *fn* to *items* using the backend's execution strategy."""
+        ...
 
 
 class JoblibBackend:
@@ -18,6 +24,7 @@ class JoblibBackend:
     def map(
         self, fn: Callable[[T], R], items: Sequence[T], *, workers: int | None = None
     ) -> List[R]:
+        """Execute *fn* over *items* using joblib when available."""
         try:
             from joblib import Parallel, delayed  # type: ignore
         except Exception:
@@ -27,4 +34,5 @@ class JoblibBackend:
 
 
 def sequential_map(fn: Callable[[T], R], items: Iterable[T]) -> List[R]:
+    """Apply *fn* to *items* sequentially and return the collected results."""
     return [fn(x) for x in items]
